@@ -53,7 +53,7 @@ setOldClass("NoiseKriging")
 #' @slot NoiseKriging A copy of the \code{NoiseKriging} object used to create
 #'     the current \code{NoiseKM} object.
 #' 
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @name NoiseKM-class
 #' @rdname NoiseKM-class
@@ -76,7 +76,7 @@ setClass("NoiseKM", slots = c("NoiseKriging" = "NoiseKriging"), contains = "km")
 #'
 #' @title Create an \code{NoiseKM} Object
 #' 
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #' 
 #' @param formula R formula object to setup the linear trend in
 #'     Universal NoiseKriging. Supports \code{~ 1}, ~. and \code{~ .^2}.
@@ -198,17 +198,17 @@ NoiseKM <- function(formula = ~1, design, response,
     
     parameters <- list()
     if (!is.null(coef.var))
-        parameters <- c(parameters, list(sigma2 = coef.var))
+        parameters <- c(parameters, list(sigma2 = coef.var, is_sigma2_estim=FALSE))
     if (!is.null(coef.cov)) {
         parameters <- c(parameters,
-                        list(theta = matrix(coef.cov, ncol = ncol(design))))
+                        list(theta = matrix(coef.cov, ncol = ncol(design)), is_theta_estim=FALSE))
         optim.method <- "none"
         ## XXXY 
         warning("Since 'coef.cov' is provided 'optim.method' is set to ",
                 "\"none\"")
     }  
     if (!is.null(coef.trend)) {
-        parameters <- c(parameters, list(beta = matrix(coef.trend)))
+        parameters <- c(parameters, list(beta = matrix(coef.trend), is_beta_estim=FALSE))
     }
     if (!is.null(parinit)) {
         parameters <- c(parameters,
@@ -260,7 +260,7 @@ predict.NoiseKM <- function(object, newdata, type = "UK",
     if (type != "UK") stop("'type != UK' unsupported.")
     
     y.predict <- predict.NoiseKriging(object@NoiseKriging, x = newdata,
-                                 stdev = se.compute, cov = cov.compute)
+                                 return_stdev = se.compute, return_cov = cov.compute)
     
     output.list <- list()
     ## output.list$trend <- y.predict.trend
@@ -303,7 +303,7 @@ predict.NoiseKM <- function(object, newdata, type = "UK",
 #' 
 #' @title Prediction Method for a \code{NoiseKM} Object
 #' 
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #' 
 #' @param object \code{NoiseKM} object.
 #' @param newdata Matrix of "new" input points where to perform
@@ -383,7 +383,7 @@ simulate.NoiseKM <- function(object, nsim = 1, seed = NULL, newdata,
 #'
 #' @title Simulation from a \code{NoiseKM} Object
 #' 
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #' 
 #' @param object A \code{NoiseKM} object.
 #'
@@ -455,7 +455,7 @@ update.NoiseKM <- function(object,
     ## duplicate to avoid changing 'object' in an inconsistent
     ## way (
     obK <- object@NoiseKriging
-    update.NoiseKriging(obK, newy=newy, newnoise=newnoise.var, newX=newX)
+    update.NoiseKriging(obK, newy, newnoise.var, newX)
     
     return(as.km(obK))
     
@@ -477,7 +477,7 @@ update.NoiseKM <- function(object,
 #'
 #' @title Update a \code{NoiseKM} Object with New Points
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #' 
 #' @param object A NoiseKM object.
 #' @param newX A numeric matrix containing the new design points. It
