@@ -19,6 +19,8 @@ void logLikelihoodFun(int nlhs, mxArray** plhs, int nrhs, const mxArray** prhs);
 void logMargPostFun(int nlhs, mxArray** plhs, int nrhs, const mxArray** prhs);
 void logLikelihood(int nlhs, mxArray** plhs, int nrhs, const mxArray** prhs);
 void logMargPost(int nlhs, mxArray** plhs, int nrhs, const mxArray** prhs);
+void covMat(int nlhs, mxArray** plhs, int nrhs, const mxArray** prhs);
+void model(int nlhs, mxArray** plhs, int nrhs, const mxArray** prhs);
 
 void kernel(int nlhs, mxArray** plhs, int nrhs, const mxArray** prhs);
 void optim(int nlhs, mxArray** plhs, int nrhs, const mxArray** prhs);
