@@ -20,7 +20,7 @@ case "$(uname -s)" in
    ;;
 esac
 
-ROOT_DIR=/home/richet/Sync/Open/libKriging/alien/rlibKriging
+ROOT_DIR=/home/richet/Sync/Open/libKriging/alien/rlibkriging-master
 if [[ "$ENABLE_PYTHON_BINDING" == "on" ]]; then
   if ( command -v python3 >/dev/null 2>&1 && python3 -m pip --version >/dev/null 2>&1 ); then
     # python3 -m pip install pip # --upgrade # --progress-bar off
