@@ -6,8 +6,8 @@
   #export PATH=${HOME}/Miniconda3:$PATH
 # fi
 
+# Octave MinGW (put first to ensure we use Octave's compiler toolchain)
+export PATH=/c/ProgramData/Chocolatey/lib/octave.portable/tools/octave/mingw64/bin:${PATH}
+
 # make
 export PATH="/c/Program Files/make/make-4.3/bin":${PATH}
-
-# Octave shortcut (after all to avoid to use Octave incompatible dev tools) by Chocolatey
-export PATH=$PATH:/c/ProgramData/Chocolatey/lib/octave.portable/tools/octave/mingw64/bin
