@@ -9,6 +9,15 @@ BASEDIR=$(dirname "$0")
 BASEDIR=$(cd "$BASEDIR" && pwd -P)
 test -f "${BASEDIR}"/loadenv.sh && . "${BASEDIR}"/loadenv.sh 
 
+# Add MKL library path if MKL is installed
+if [[ "$(uname -s)" == "Linux" && -d /opt/intel/oneapi/mkl/latest/lib ]]; then
+  export LD_LIBRARY_PATH=/opt/intel/oneapi/mkl/latest/lib:${LD_LIBRARY_PATH}
+  echo "Added MKL library path to LD_LIBRARY_PATH"
+elif [[ "$(uname -s)" == "Linux" && -d /opt/intel/mkl/lib/intel64 ]]; then
+  export LD_LIBRARY_PATH=/opt/intel/mkl/lib/intel64:${LD_LIBRARY_PATH}
+  echo "Added MKL library path to LD_LIBRARY_PATH"
+fi
+
 # MacOS + Shared : OK
 # MacOS + Static : there is a bug with dependant libs not found
 # Linux + Shared : OK
@@ -26,7 +35,7 @@ fi
 
 MODE=${MODE:-Release}
 
-BUILD_TEST=false \
+BUILD_TEST=true \
     MODE=${MODE} \
     CC=$(R CMD config CC) \
     CXX=$(R CMD config CXX) \
