@@ -1,5 +1,8 @@
+if(requireNamespace('DiceKriging', quietly = TRUE)) { 
 library(testthat)
  Sys.setenv('OMP_THREAD_LIMIT'=2)
+
+library(DiceKriging)
  library(rlibkriging)
 
 context("Fit: 1D")
@@ -88,7 +91,7 @@ k <- tryCatch( # needed to catch warning due to %dopar% usage when using multist
     withCallingHandlers(
       {
         error_text <- "No error."
-        DiceKriging::km(design=X,response=y,covtype = "gauss", multistart = 1 , parinit=parinit,control = list(trace=F))
+        DiceKriging::km(design=X,response=y,covtype = "gauss", multistart=1 , parinit=parinit,control = list(trace=F))
       },
       warning = function(e) {
         error_text <<- trimws(paste0("WARNING: ", e))
@@ -226,3 +229,19 @@ points(theta_ref,col='black')
 
 test_that(desc="Fit: 2D _not_ in [0,1]^2 / fit of theta 2D is _quite_ the same that DiceKriging one",
           expect_equal(ll_r(array(as.list(r)$theta)), ll_k(k@covariance@range.val), tol=1e-1))
+}
+
+if (file.exists("fit-2d-multistart.Rdata")) {
+  file.remove("fit-2d-multistart.Rdata")
+}
+
+
+if (file.exists("fit-2d.Rdata")) {
+  file.remove("fit-2d.Rdata")
+}
+
+
+if (file.exists("fit-2d-not01.Rdata")) {
+  file.remove("fit-2d-not01.Rdata")
+}
+
