@@ -1,5 +1,8 @@
+if(requireNamespace('DiceKriging', quietly = TRUE)) { 
 library(testthat)
  Sys.setenv('OMP_THREAD_LIMIT'=2)
+
+library(DiceKriging)
  library(rlibkriging)
 
 for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
@@ -78,3 +81,4 @@ test_that(desc="leaveOneOut vector mean is equal to DiceKriging one",
           expect_equal(loovec_km$mean,loovec$mean[,1],tolerance= precision))
 test_that(desc="leaveOneOut vector stdev is equal to DiceKriging one",
           expect_equal(loovec_km$sd,loovec$stdev[,1],tolerance= precision))
+}
