@@ -1,5 +1,8 @@
+if(requireNamespace('DiceKriging', quietly = TRUE)) { 
 library(testthat)
  Sys.setenv('OMP_THREAD_LIMIT'=2)
+
+library(DiceKriging)
  library(rlibkriging)
 
 for (kernel in c("gauss","exp")) {
@@ -28,3 +31,4 @@ test_that(desc="leaveOneOut is the same that DiceKriging one",
 test_that(desc="leaveOneOut Grad is the same that DiceKriging one",
           expect_equal(t(leaveOneOutFun(r,x,return_grad=T)$leaveOneOutGrad),DiceKriging::leaveOneOutGrad(x,k,xenv),tolerance= precision))
 }
+}
