@@ -1,6 +1,9 @@
+if(requireNamespace('DiceKriging', quietly = TRUE)) { 
 if(requireNamespace('RobustGaSP', quietly = TRUE)) {
 library(testthat)
  Sys.setenv('OMP_THREAD_LIMIT'=2)
+
+library(DiceKriging)
  library(rlibkriging)
 
 ##library(rlibkriging, lib.loc="bindings/R/Rlibs")
@@ -106,3 +109,4 @@ test_that(desc=paste0("pred mean is the same that RobustGaSP one"),
 test_that(desc=paste0("pred sd is the same that RobustGaSP one"),
           expect_equal(predict(r,c(0.7,x2))$stdev[1],predict(k,matrix(c(0.7,x2),ncol=2))$sd,tol = precision))
 }
+}
