@@ -1,6 +1,9 @@
+if(requireNamespace('DiceKriging', quietly = TRUE)) { 
 if(requireNamespace('RobustGaSP', quietly = TRUE)) {
 library(testthat)
  Sys.setenv('OMP_THREAD_LIMIT'=2)
+
+library(DiceKriging)
  library(rlibkriging)
 
 ##library(rlibkriging, lib.loc="bindings/R/Rlibs")
@@ -272,3 +275,4 @@ precision <- 1e-1
 test_that(desc=paste0("Fit: 2D (Branin) / rgasp/lmp deriv is the same that lk/lmp deriv"),
           expect_equal(dlmp_rgasp(c(1,1)),-exp(-1)*dlmp_lk(c(1,1)),tol = precision))
 }
+}
