@@ -1,5 +1,8 @@
+if(requireNamespace('DiceKriging', quietly = TRUE)) { 
 library(testthat)
  Sys.setenv('OMP_THREAD_LIMIT'=2)
+
+library(DiceKriging)
  library(rlibkriging)
 
 ##library(rlibkriging, lib.loc="bindings/R/Rlibs")
@@ -65,10 +68,10 @@ library(DiceKriging)
 ## kriging model 1 : matern5_2 covariance structure, no trend, no nugget effect
 km1 <- DiceKriging::km(design = design.fact, response = y, covtype = "gauss",
           parinit = c(.5, 1), control = list(trace = FALSE))
-rlibkriging:::optim_log(3)
+rlibkriging:::optim_set_log_level(3)
 KM1 <- rlibkriging::KM(design = design.fact, response = y, covtype = "gauss",
           parinit = c(.5, 1))
-rlibkriging:::optim_log(0)
+rlibkriging:::optim_set_log_level(0)
 
 test_that("m1.logLikFun == as_m1.logLikFun",
           expect_true(DiceKriging::logLikFun(km1@covariance@range.val, km1) ==
@@ -332,3 +335,4 @@ for (f in c( ~1 , ~. , ~.^2 ))
             test_args(formula = f, design = X,
                       response = y, covtype = co, estim.method = e)
     }
+}
